@@ -1,3 +1,5 @@
+import json
+
 import aio_pika
 
 
@@ -15,7 +17,7 @@ class QueueAsyncClient:
             if self.exchange is None:
                 self.exchange = await self.channel.declare_exchange(
                     self.exchange_name,
-                    aio_pika.ExchangeType.FANOUT
+                    aio_pika.ExchangeType.DIRECT
                 )
 
             queue = await self.channel.declare_queue(exclusive=True)
@@ -24,7 +26,9 @@ class QueueAsyncClient:
             async with queue.iterator() as queue_iter:
                 async for message in queue_iter:
                     async with message.process():
-                        await callback(message.body)
+                        decoded_message = message.body.decode('utf-8')
+                        payload = json.loads(decoded_message)
+                        await callback(payload)
 
     async def close(self):
         if self.connection:
